@@ -1,4 +1,4 @@
-# $Id: /local/Mango/trunk/lib/Mango/Exception.pm 150 2007-04-14T02:57:04.324056Z claco  $
+# $Id: /local/Mango/trunk/lib/Mango/Exception.pm 163 2007-04-20T02:21:55.419198Z claco  $
 package Mango::Exception;
 use strict;
 use warnings;
@@ -34,13 +34,13 @@ __END__
 
 =head1 NAME
 
-Mango::Exception - Exception classes used in Mango
+Mango::Exception - Module representing an exception or error condition
 
 =head1 SYNOPSIS
 
     use Mango::Exception;
     
-    throw Mango::Exception('Boom!');
+    Mango::Exception->throw('Boom!');
 
 =head1 DESCRIPTION
 
@@ -57,17 +57,17 @@ for Mango based exceptions.
 
 =back
 
-When creating or throwing a new exception, you can pass in either Error-style
+When creating or throwing a new exception, you can pass in Error-style
 arguments, or just a plain old message string.
 
-    throw Mango::Exception('Boom!');
-    throw Mango::Exception(-text => 'Boom!', -line => 27, ...);
+    Mango::Exception->throw('Boom!');
+    Mango::Exception->throw(-text => 'Boom!', -line => 27, ...);
 
 Any message passed in will automatically be translated using Mango::I18N.
 
 =head1 SEE ALSO
 
-L<Handel::Iterator>
+L<Mango::I18N>, L<Error>
 
 =head1 AUTHOR
 
