@@ -1,4 +1,4 @@
-# $Id: /local/Mango/trunk/lib/Mango/Wishlist.pm 155 2007-04-16T02:58:37.637652Z claco  $
+# $Id: /local/Mango/trunk/lib/Mango/Wishlist.pm 167 2007-04-21T03:53:20.211692Z claco  $
 package Mango::Wishlist;
 use strict;
 use warnings;
@@ -31,11 +31,11 @@ __PACKAGE__->result_iterator_class('Mango::Iterator');
 __PACKAGE__->create_accessors;
 
 sub type {
-    throw Mango::Exception('METHOD_NOT_IMPLEMENTED');
+    Mango::Exception->throw('METHOD_NOT_IMPLEMENTED');
 };
 
 sub save {
-    throw Mango::Exception('METHOD_NOT_IMPLEMENTED');
+    Mango::Exception->throw('METHOD_NOT_IMPLEMENTED');
 };
 
 sub update {
@@ -51,7 +51,7 @@ __END__
 
 =head1 NAME
 
-Mango::Wishlist - Module for maintaining wishlist contents
+Mango::Wishlist - Module representing a wishlist
 
 =head1 SYNOPSIS
 
@@ -65,17 +65,18 @@ Mango::Wishlist - Module for maintaining wishlist contents
         price    => 1.25
     });
     
-    my $iterator = $wishlist->items;
-    while (my $item = $iterator->next) {
+    my $items = $wishlist->items;
+    while (my $item = $items->next) {
         print $item->sku;
         print $item->price;
         print $item->total;
     };
-    $item->subtotal;
+    print $wishlist->subtotal;
 
 =head1 DESCRIPTION
 
-Mango::Wishlist is component for maintaining simple wishlist data.
+Mango::Wishlist represents a users wishlist and wishlist contents. A wishlist
+is simply cart that has been saved and given a name for later use.
 
 =head1 METHODS
 
@@ -87,9 +88,8 @@ Mango::Wishlist is component for maintaining simple wishlist data.
 
 =back
 
-Adds a new item to the current wishlist and returns an instance of the
-item class. You can either pass the item
-data as a hash reference:
+Adds a new item to the current wishlist and returns the new item. You can
+pass in the item data as a hash reference:
 
     my $item = $wishlist->add({
         sku      => 'SKU1234',
@@ -97,16 +97,17 @@ data as a hash reference:
         price    => 1.25
     });
 
-or pass an existing cart item:
+or pass an existing wishlist/cart item:
 
     $wishlist->add(
         $cart->items({sku => 'ABC-123'})->first
     );
 
-When passing an existing cart item to add, all columns in the source item will
-be copied into the destination item if the column exists in both the
-destination and source, and the column isn't the primary key or the foreign
-key of the item relationship.
+When passing an existing item to add, all columns in the source item will
+be copied into the destination item if the column exists in the destination and
+the column isn't the primary key or the foreign key of the item relationship.
+
+The item object passed to add must be an instance or subclass of Handel::Cart.
 
 =head2 clear
 
@@ -116,10 +117,16 @@ Deletes all items from the current wishlist.
 
 =head2 count
 
-Returns the number of items in the wishlist object.
+Returns the number of items in the wishlist.
 
     my $numitems = $wishlist->count;
 
+=head2 created
+
+Returns the date and time in UTC the wishlist was created as a DateTime object.
+
+    print $wishlist->created;
+
 =head2 delete
 
 =over
@@ -128,15 +135,33 @@ Returns the number of items in the wishlist object.
 
 =back
 
-Deletes the item matching the supplied filter from the current wishlist.
+Deletes the item(s) matching the supplied filter from the current wishlist.
 
     $wishlist->delete({
         sku => 'ABC-123'
     });
 
+=head2 description
+
+=over
+
+=item Arguments: $description
+
+=back
+
+Gets/sets the description of the current wishlist.
+
+    print $wishlist->description;
+
 =head2 destroy
 
-Deletes the current item from the provider.
+Deletes the current wishlist and all of its items.
+
+=head2 id
+
+Returns the id of the current wishlist.
+
+    print $wishlist->id;
 
 =head2 items
 
@@ -151,6 +176,7 @@ L<Mango::Iterator|Mango::Iterator> in scalar context, or a list of items in
 list context.
 
     my $iterator = $wishlist->items;
+    
     while (my $item = $iterator->next) {
         print $item->sku;
     };
@@ -170,76 +196,6 @@ style syntax:
 
 =back
 
-=head2 restore
-
-=over
-
-=item Arguments: \%filter [, $mode]
-
-=item Arguments: $cart [, $mode]
-
-=back
-
-Copies (restores) items from a cart, or a set of carts back into the current
-shopping cart. You may either pass in a hash reference containing the search
-criteria of the shopping cart(s) to restore:
-
-    $wishlist->restore({
-        shopper => 'D597DEED-5B9F-11D1-8DD2-00AA004ABD5E',
-        type    => CART_TYPE_SAVED
-    });
-
-or you can pass in an existing C<Mango::Cart> object or subclass.
-
-    my $cart = $provider->search({
-        id   => 23,
-        type => CART_TYPE_SAVED
-    })->first;
-    
-    $wishlist->restore($cart);
-
-For either method, you may also specify the mode in which the cart should be
-restored. The following modes are available:
-
-=over
-
-=item C<CART_MODE_REPLACE>
-
-All items in the current wishlist will be deleted before the saved cart is restored
-into it. This is the default if no mode is specified.
-
-=item C<CART_MODE_MERGE>
-
-If an item with the same SKU exists in both the current cart and the saved cart,
-the quantity of each will be added together and applied to the same sku in the
-current cart. Any price differences are ignored and we assume that the price in
-the current cart has the more up to date price.
-
-=item C<CART_MODE_APPEND>
-
-All items in the saved cart will be appended to the list of items in the current
-cart. No effort will be made to merge items with the same SKU and duplicates
-will be ignored.
-
-=back
-
-=head2 id
-
-Returns the id of the current wishlist.
-
-    print $wishlist->id;
-
-=head2 subtotal
-
-Returns the current total price of all the items in the wishlist object as a
-stringified L<Mango::Currency|Mango::Currency> object. This is equivalent to:
-
-    my $iterator = $wishlist->items;
-    my $subtotal = 0;
-    while (my $item = $iterator->next) {
-        $subtotal += $item->quantity*$item->price;
-    };
-
 =head2 name
 
 =over
@@ -252,37 +208,90 @@ Gets/sets the name of the current wishlist.
 
     print $wishlist->name;
 
-=head2 description
+=head2 restore
 
 =over
 
-=item Arguments: $description
+=item Arguments: \%filter [, $mode]
+
+=item Arguments: $cart [, $mode]
 
 =back
 
-Gets/sets the description of the current wishlist.
+Copies (restores) items from a cart/wishlist, or a set of carts/wishlist back
+into the current cart. You may either pass in a hash reference containing the
+search criteria of the cart(s) to restore:
 
-    print $wishlist->description;
+    $cart->restore({
+        id => 23
+    });
 
-=head2 created
+or you can pass in an existing C<Mango::Cart> or C<Mango::Wishlist> object
+or subclass.
 
-Returns the date the wishlist was created as a DateTime object.
+    my $cart = Mango::Cart->search({
+        id   => 23
+    })->first;
+    
+    $wishlist->restore($cart);
 
-    print $wishlist->created;
+For either method, you may also specify the mode in which the wishlist should be
+restored. The following modes are available:
 
-=head2 updated
+=over
 
-Returns the date the wishlist was last updated as a DateTime object.
+=item C<WISHLIST_MODE_REPLACE>
 
-    print $wishlist->updated;
+All items in the current wishlist will be deleted before the cart is restored
+into it. This is the default if no mode is specified.
+
+=item C<WISHLIST_MODE_MERGE>
+
+If an item with the same SKU exists in both the current wishlist and the saved
+cart, the quantity of each will be added together and applied to
+the same sku in the current wishlist. Any price differences are ignored and we
+assume that the price in the current wishlist has the more up to date price.
+
+=item C<WISHLIST_MODE_APPEND>
+
+All items in the cart will be appended to the list of items in the current
+wishlist. No effort will be made to merge items with the same SKU and
+duplicates will be allowed.
+
+=back
+
+=head2 subtotal
+
+Returns the current total price of all the items in the wishlist as a
+L<Mango::Currency|Mango::Currency> object. This is equivalent to:
+
+    my $items = $wishlist->items;
+    my $subtotal = 0;
+    
+    while (my $item = $items->next) {
+        $subtotal += $item->quantity*$item->price;
+    };
 
 =head2 update
 
-Saves any changes to the wishlist back to the provider.
+Saves any changes made to the wishlist back to the provider.
+
+    $wishlist->user(23);
+    $wishlist->update;
+
+Whenever L</update> is called, L</updated> is automatically set to the
+current time in UTC.
+
+=head2 updated
+
+Returns the date and time in UTC the wishlist was last updated as a DateTime
+object.
+
+    print $wishlist->updated;
 
 =head1 SEE ALSO
 
-L<Mango::Cart::Item>, L<Mango::Schema::Cart::Item>
+L<Mango::Wishlist::Item>, L<Mango::Schema::Wishlist>
 
 =head1 AUTHOR
 
